// NUDISDK.H	// these contains the declaration of SDK functions
// and other constants
// Developped By: Harsha Kodnad



#if !defined ( _NUDISDK_H_ )
#define _NUDISDK_H_


// called by C calling sequence
#define NUDIAPI				extern "C"

// errors returned by Nudi SDK and Values

#define NUDI_SUCCESS						1
#define NUDI_FAILURE						0

#define NUDI_ERR_SYSTEM						-1
#define NUDI_ERR_ALREADY_RUNNING			-2
#define NUDI_ERR_NOT_RUNNING				-3
#define NUDI_ERR_MEMORY_INSUFITIENT			-4
#define NUDI_ERR_INVALID_PARAMETER			-5
#define NUDI_ERR_IN_CONVERSION_PARAMETER	-6
#define NUDI_ERR_NO_SUPPORT					-7

#define NUDI_CMP_FAILURE					999


// Nudi font types.
#define NUDI_FONT_BI						0
#define NUDI_FONT_MONO						1
#define NUDI_FONT_UNICODE					2

// NUDI Engine Toggle Key Type
#define NUDI_TOGGLE_KEY_SCROLL_LOCK			0
#define NUDI_TOGGLE_KEY_F12					1


NUDIAPI BOOL NudiStartKeyboardEngine ( BOOL isGlobal, INT fontType, BOOL needTrayIcon );
NUDIAPI BOOL NudiStopKeyboardEngine ();
NUDIAPI BOOL NudiIsEngineRunning ();
NUDIAPI BOOL NudiChangeEngineType ( BOOL isGlobal);
NUDIAPI BOOL NudiChangeFontType ( INT  fontType );
NUDIAPI BOOL NudiTurnOffScrollLock ();
NUDIAPI BOOL NudiTurnOnScrollLock ();
NUDIAPI void NudiResetAllFlags ();
NUDIAPI BOOL NudiSendCharacters ( unsigned char * SendChar );

NUDIAPI int NudiMonolingualGlyphCompare ( unsigned char * glyphString1, unsigned char * glyphString2 );
NUDIAPI int NudiBilingualGlyphCompare ( unsigned char * glyphString1, unsigned char * glyphString2 );

NUDIAPI int NudiISCII2MonolingualGlyph ( unsigned char * isciiString, unsigned char * glyphString, 
							   unsigned int maxLen );
NUDIAPI int NudiISCII2BilingualGlyph ( unsigned char * isciiString, unsigned char * glyphString, 
							   unsigned int maxLen );

NUDIAPI int NudiMonolingualGlyph2ISCII ( unsigned char * glyphString, unsigned char * isciiString, 
								unsigned int maxLen );
NUDIAPI int NudiBilingualGlyph2ISCII ( unsigned char * glyphString, unsigned char * isciiString, 
								unsigned int maxLen );

NUDIAPI int NudiMonolingualGlyph2KSCLP ( unsigned char * glyphString, unsigned char * ksclpString, 
							   unsigned int maxLen );
NUDIAPI int NudiBilingualGlyph2KSCLP ( unsigned char * glyphString, unsigned char * ksclpString, 
							   unsigned int maxLen );
NUDIAPI INT NudiMonolingualGlyph2Unicode ( unsigned char * glyphString, unsigned short * unicodeStr, 
							   unsigned int maxLen );
NUDIAPI INT NudiBilingualGlyph2Unicode ( IN unsigned char * glyphString, OUT unsigned short * unicodeStr, 
							   IN unsigned int maxLen );
NUDIAPI INT NudiISCII2Unicode ( IN unsigned char * isciiStr, OUT unsigned short * unicodeStr, 
							   IN unsigned int maxLen );
NUDIAPI INT NudiUnicode2ISCII ( unsigned short * unicodeStr, unsigned char * isciiStr, unsigned int maxLen );
NUDIAPI int 
NudiMonolingual2BilingualGlyph ( unsigned char * monoString, unsigned char * biString, unsigned int maxLen );
NUDIAPI int 
NudiBilingual2MonolingualGlyph ( unsigned char * biString, unsigned char * monoString, unsigned int maxLen );
NUDIAPI int NudiText2Hex ( IN unsigned char * Kgp, OUT unsigned char * HexDec, IN unsigned int maxLen );

NUDIAPI int NudiGetLastError();
NUDIAPI void NudiSetLastError( IN int pVal );

NUDIAPI int NudiGetCurrentFontType ();
NUDIAPI BOOL NudiIsUnicodeSupported();

// Top level control of Engine. // this should be on, irrespective of Scroll Lock or Any Other
// Keys like F11 etc.
NUDIAPI BOOL NudiTurnEngineOn ();
NUDIAPI BOOL NudiTurnEngineOff ();
NUDIAPI BOOL NudiIsEngineOn ();
NUDIAPI BOOL NudiSetEngineToggleKey ( INT pToggleKey );
NUDIAPI int  NudiGetEngineToggleKey ();

NUDIAPI void NudiSetEngineCallBack ( FARPROC pProc );
NUDIAPI void NudiResetEngineCallBack (void);

#endif  // _NUDISDK_H_
